@@ -5,16 +5,18 @@ from typing import Annotated
 
 import cyclopts
 import questionary
-from rich.console import Console
 from rich.table import Table
 
 from sqlsaber.config.database import DatabaseConfigManager
+from sqlsaber.config.logging import get_logger
 from sqlsaber.memory.manager import MemoryManager
+from sqlsaber.theme.manager import create_console
 
 # Global instances for CLI commands
-console = Console()
+console = create_console()
 config_manager = DatabaseConfigManager()
 memory_manager = MemoryManager()
+logger = get_logger(__name__)
 
 # Create the memory management CLI app
 memory_app = cyclopts.App(
@@ -29,17 +31,19 @@ def _get_database_name(database: str | None = None) -> str:
         db_config = config_manager.get_database(database)
         if not db_config:
             console.print(
-                f"[bold red]Error:[/bold red] Database connection '{database}' not found."
+                f"[bold error]Error:[/bold error] Database connection '{database}' not found."
             )
+            logger.error("memory.db.not_found", database=database)
             sys.exit(1)
         return database
     else:
         db_config = config_manager.get_default_database()
         if not db_config:
             console.print(
-                "[bold red]Error:[/bold red] No database connections configured."
+                "[bold error]Error:[/bold error] No database connections configured."
             )
             console.print("Use 'sqlsaber db add <name>' to add a database connection.")
+            logger.error("memory.db.none_configured")
             sys.exit(1)
         return db_config.name
 
@@ -57,14 +61,17 @@ def add(
 ):
     """Add a new memory for the specified database."""
     database_name = _get_database_name(database)
+    logger.info("memory.add.start", database=database_name)
 
     try:
         memory = memory_manager.add_memory(database_name, content)
         console.print(f"[green]✓ Memory added for database '{database_name}'[/green]")
         console.print(f"[dim]Memory ID:[/dim] {memory.id}")
         console.print(f"[dim]Content:[/dim] {memory.content}")
+        logger.info("memory.add.success", database=database_name, id=memory.id)
     except Exception as e:
-        console.print(f"[bold red]Error adding memory:[/bold red] {e}")
+        console.print(f"[bold error]Error adding memory:[/bold error] {e}")
+        logger.exception("memory.add.error", database=database_name, error=str(e))
         sys.exit(1)
 
 
@@ -80,14 +87,16 @@ def list(
 ):
     """List all memories for the specified database."""
     database_name = _get_database_name(database)
+    logger.info("memory.list.start", database=database_name)
 
     memories = memory_manager.get_memories(database_name)
 
     if not memories:
         console.print(
-            f"[yellow]No memories found for database '{database_name}'[/yellow]"
+            f"[warning]No memories found for database '{database_name}'[/warning]"
         )
         console.print("Use 'sqlsaber memory add \"<content>\"' to add memories")
+        logger.info("memory.list.empty", database=database_name)
         return
 
     table = Table(title=f"Memories for Database: {database_name}")
@@ -105,6 +114,7 @@ def list(
 
     console.print(table)
     console.print(f"\n[dim]Total memories: {len(memories)}[/dim]")
+    logger.info("memory.list.complete", database=database_name, count=len(memories))
 
 
 @memory_app.command
@@ -120,13 +130,15 @@ def show(
 ):
     """Show the full content of a specific memory."""
     database_name = _get_database_name(database)
+    logger.info("memory.show.start", database=database_name, id=memory_id)
 
     memory = memory_manager.get_memory_by_id(database_name, memory_id)
 
     if not memory:
         console.print(
-            f"[bold red]Error:[/bold red] Memory with ID '{memory_id}' not found for database '{database_name}'"
+            f"[bold error]Error:[/bold error] Memory with ID '{memory_id}' not found for database '{database_name}'"
         )
+        logger.error("memory.show.not_found", database=database_name, id=memory_id)
         sys.exit(1)
 
     console.print(f"[bold]Memory ID:[/bold] {memory.id}")
@@ -149,27 +161,31 @@ def remove(
 ):
     """Remove a specific memory by ID."""
     database_name = _get_database_name(database)
+    logger.info("memory.remove.start", database=database_name, id=memory_id)
 
     # First check if memory exists
     memory = memory_manager.get_memory_by_id(database_name, memory_id)
     if not memory:
         console.print(
-            f"[bold red]Error:[/bold red] Memory with ID '{memory_id}' not found for database '{database_name}'"
+            f"[bold error]Error:[/bold error] Memory with ID '{memory_id}' not found for database '{database_name}'"
         )
+        logger.error("memory.remove.not_found", database=database_name, id=memory_id)
         sys.exit(1)
 
     # Show memory content before removal
-    console.print("[yellow]Removing memory:[/yellow]")
+    console.print("[warning]Removing memory:[/warning]")
     console.print(f"[dim]Content:[/dim] {memory.content}")
 
     if memory_manager.remove_memory(database_name, memory_id):
         console.print(
             f"[green]✓ Memory removed from database '{database_name}'[/green]"
         )
+        logger.info("memory.remove.success", database=database_name, id=memory_id)
     else:
         console.print(
-            f"[bold red]Error:[/bold red] Failed to remove memory '{memory_id}'"
+            f"[bold error]Error:[/bold error] Failed to remove memory '{memory_id}'"
         )
+        logger.error("memory.remove.failed", database=database_name, id=memory_id)
         sys.exit(1)
 
 
@@ -192,30 +208,34 @@ def clear(
 ):
     """Clear all memories for the specified database."""
     database_name = _get_database_name(database)
+    logger.info("memory.clear.start", database=database_name, force=bool(force))
 
     # Count memories first
     memories_count = len(memory_manager.get_memories(database_name))
 
     if memories_count == 0:
         console.print(
-            f"[yellow]No memories to clear for database '{database_name}'[/yellow]"
+            f"[warning]No memories to clear for database '{database_name}'[/warning]"
         )
+        logger.info("memory.clear.nothing", database=database_name)
         return
 
     if not force:
         # Show confirmation
         console.print(
-            f"[yellow]About to clear {memories_count} memories for database '{database_name}'[/yellow]"
+            f"[warning]About to clear {memories_count} memories for database '{database_name}'[/warning]"
         )
 
         if not questionary.confirm("Are you sure you want to proceed?").ask():
             console.print("Operation cancelled")
+            logger.info("memory.clear.cancelled", database=database_name)
             return
 
     cleared_count = memory_manager.clear_memories(database_name)
     console.print(
         f"[green]✓ Cleared {cleared_count} memories for database '{database_name}'[/green]"
     )
+    logger.info("memory.clear.success", database=database_name, deleted=cleared_count)
 
 
 @memory_app.command
@@ -230,6 +250,7 @@ def summary(
 ):
     """Show memory summary for the specified database."""
     database_name = _get_database_name(database)
+    logger.info("memory.summary.start", database=database_name)
 
     summary = memory_manager.get_memories_summary(database_name)
 
@@ -240,6 +261,11 @@ def summary(
         console.print("\n[bold]Recent memories:[/bold]")
         for memory in summary["memories"][-5:]:  # Show last 5 memories
             console.print(f"[dim]{memory['timestamp']}[/dim] - {memory['content']}")
+    logger.info(
+        "memory.summary.complete",
+        database=database_name,
+        total=summary["total_memories"],
+    )
 
 
 def create_memory_app() -> cyclopts.App:
