@@ -12,10 +12,14 @@ from rich.markdown import Markdown
 from rich.panel import Panel
 from rich.table import Table
 
+from sqlsaber.config.logging import get_logger
+from sqlsaber.theme.manager import create_console, get_theme_manager
 from sqlsaber.threads import ThreadStorage
 
 # Globals consistent with other CLI modules
-console = Console()
+console = create_console()
+tm = get_theme_manager()
+logger = get_logger(__name__)
 
 
 threads_app = cyclopts.App(
@@ -84,13 +88,23 @@ def _render_transcript(
                         console.print(f"**User:**\n\n{text}\n")
                     else:
                         console.print(
-                            Panel.fit(Markdown(text), title="User", border_style="cyan")
+                            Panel.fit(
+                                Markdown(text, code_theme=tm.pygments_style_name),
+                                title="User",
+                                border_style=tm.style("panel.border.user"),
+                            )
                         )
                     return
         if is_redirected:
             console.print("**User:** (no content)\n")
         else:
-            console.print(Panel.fit("(no content)", title="User", border_style="cyan"))
+            console.print(
+                Panel.fit(
+                    "(no content)",
+                    title="User",
+                    border_style=tm.style("panel.border.user"),
+                )
+            )
 
     def _render_response(message: ModelMessage) -> None:
         for part in getattr(message, "parts", []):
@@ -103,7 +117,9 @@ def _render_transcript(
                     else:
                         console.print(
                             Panel.fit(
-                                Markdown(text), title="Assistant", border_style="green"
+                                Markdown(text, code_theme=tm.pygments_style_name),
+                                title="Assistant",
+                                border_style=tm.style("panel.border.assistant"),
                             )
                         )
             elif kind in ("tool-call", "builtin-tool-call"):
@@ -148,24 +164,28 @@ def _render_transcript(
                             )
                         else:
                             if is_redirected:
-                                console.print(f"**Tool result ({name}):**\n\n{content_str}\n")
+                                console.print(
+                                    f"**Tool result ({name}):**\n\n{content_str}\n"
+                                )
                             else:
                                 console.print(
                                     Panel.fit(
                                         content_str,
                                         title=f"Tool result: {name}",
-                                        border_style="yellow",
+                                        border_style="warning",
                                     )
                                 )
                     except Exception:
                         if is_redirected:
-                            console.print(f"**Tool result ({name}):**\n\n{content_str}\n")
+                            console.print(
+                                f"**Tool result ({name}):**\n\n{content_str}\n"
+                            )
                         else:
                             console.print(
                                 Panel.fit(
                                     content_str,
                                     title=f"Tool result: {name}",
-                                    border_style="yellow",
+                                    border_style="warning",
                                 )
                             )
                 else:
@@ -176,7 +196,7 @@ def _render_transcript(
                             Panel.fit(
                                 content_str,
                                 title=f"Tool result: {name}",
-                                border_style="yellow",
+                                border_style="warning",
                             )
                         )
         # Thinking parts omitted
@@ -201,17 +221,19 @@ def list_threads(
     ] = 50,
 ):
     """List threads (optionally filtered by database)."""
+    logger.info("threads.cli.list.start", database=database, limit=limit)
     store = ThreadStorage()
     threads = asyncio.run(store.list_threads(database_name=database, limit=limit))
     if not threads:
         console.print("No threads found.")
+        logger.info("threads.cli.list.empty")
         return
     table = Table(title="Threads")
-    table.add_column("ID", style="cyan")
-    table.add_column("Database", style="magenta")
-    table.add_column("Title", style="green")
-    table.add_column("Last Activity", style="dim")
-    table.add_column("Model", style="yellow")
+    table.add_column("ID", style=tm.style("info"))
+    table.add_column("Database", style=tm.style("accent"))
+    table.add_column("Title", style=tm.style("success"))
+    table.add_column("Last Activity", style=tm.style("muted"))
+    table.add_column("Model", style=tm.style("warning"))
     for t in threads:
         table.add_row(
             t.id,
@@ -221,6 +243,7 @@ def list_threads(
             t.model_name or "-",
         )
     console.print(table)
+    logger.info("threads.cli.list.complete", count=len(threads))
 
 
 @threads_app.command
@@ -228,10 +251,12 @@ def show(
     thread_id: Annotated[str, cyclopts.Parameter(help="Thread ID")],
 ):
     """Show thread metadata and render the full transcript."""
+    logger.info("threads.cli.show.start", thread_id=thread_id)
     store = ThreadStorage()
     thread = asyncio.run(store.get_thread(thread_id))
     if not thread:
-        console.print(f"[red]Thread not found:[/red] {thread_id}")
+        console.print(f"[error]Thread not found:[/error] {thread_id}")
+        logger.error("threads.cli.show.not_found", thread_id=thread_id)
         return
     msgs = asyncio.run(store.get_thread_messages(thread_id))
     console.print(f"[bold]Thread: {thread.id}[/bold]")
@@ -243,6 +268,7 @@ def show(
     console.print("")
 
     _render_transcript(console, msgs, None)
+    logger.info("threads.cli.show.complete", thread_id=thread_id)
 
 
 @threads_app.command
@@ -254,14 +280,15 @@ def resume(
     ] = None,
 ):
     """Render transcript, then resume thread in interactive mode."""
+    logger.info("threads.cli.resume.start", thread_id=thread_id, database=database)
     store = ThreadStorage()
 
     async def _run() -> None:
         # Lazy imports to avoid heavy modules at CLI startup
-        from sqlsaber.agents import build_sqlsaber_agent
+        from sqlsaber.agents import SQLSaberAgent
         from sqlsaber.cli.interactive import InteractiveSession
         from sqlsaber.config.database import DatabaseConfigManager
-        from sqlsaber.database.connection import DatabaseConnection
+        from sqlsaber.database import DatabaseConnection
         from sqlsaber.database.resolver import (
             DatabaseResolutionError,
             resolve_database,
@@ -269,13 +296,15 @@ def resume(
 
         thread = await store.get_thread(thread_id)
         if not thread:
-            console.print(f"[red]Thread not found:[/red] {thread_id}")
+            console.print(f"[error]Thread not found:[/error] {thread_id}")
+            logger.error("threads.cli.resume.not_found", thread_id=thread_id)
             return
         db_selector = database or thread.database_name
         if not db_selector:
             console.print(
-                "[red]No database specified or stored with this thread.[/red]"
+                "[error]No database specified or stored with this thread.[/error]"
             )
+            logger.error("threads.cli.resume.no_database", thread_id=thread_id)
             return
         try:
             config_manager = DatabaseConfigManager()
@@ -283,21 +312,29 @@ def resume(
             connection_string = resolved.connection_string
             db_name = resolved.name
         except DatabaseResolutionError as e:
-            console.print(f"[red]Database resolution error:[/red] {e}")
+            console.print(f"[error]Database resolution error:[/error] {e}")
+            logger.error(
+                "threads.cli.resume.resolve_failed", thread_id=thread_id, error=str(e)
+            )
             return
 
         db_conn = DatabaseConnection(connection_string)
         try:
-            agent = build_sqlsaber_agent(db_conn, db_name)
+            sqlsaber_agent = SQLSaberAgent(db_conn, db_name)
             history = await store.get_thread_messages(thread_id)
             if console.is_terminal:
-                console.print(Panel.fit(f"Thread: {thread.id}", border_style="blue"))
+                console.print(
+                    Panel.fit(
+                        f"Thread: {thread.id}",
+                        border_style=tm.style("panel.border.thread"),
+                    )
+                )
             else:
                 console.print(f"# Thread: {thread.id}\n")
             _render_transcript(console, history, None)
             session = InteractiveSession(
                 console=console,
-                agent=agent,
+                sqlsaber_agent=sqlsaber_agent,
                 db_conn=db_conn,
                 database_name=db_name,
                 initial_thread_id=thread_id,
@@ -306,7 +343,8 @@ def resume(
             await session.run()
         finally:
             await db_conn.close()
-            console.print("\n[green]Goodbye![/green]")
+            console.print("\n[success]Goodbye![/success]")
+            logger.info("threads.cli.resume.closed")
 
     asyncio.run(_run())
 
@@ -321,11 +359,13 @@ def prune(
     ] = 30,
 ):
     """Prune old threads by last activity timestamp."""
+    logger.info("threads.cli.prune.start", days=days)
     store = ThreadStorage()
 
     async def _run() -> None:
         deleted = await store.prune_threads(older_than_days=days)
-        console.print(f"[green]✓ Pruned {deleted} thread(s).[/green]")
+        console.print(f"[success]✓ Pruned {deleted} thread(s).[/success]")
+        logger.info("threads.cli.prune.complete", deleted=deleted)
 
     asyncio.run(_run())
 
