@@ -4,11 +4,11 @@ import getpass
 import os
 
 import keyring
-from rich.console import Console
 
 from sqlsaber.config import providers
+from sqlsaber.theme.manager import create_console
 
-console = Console()
+console = create_console()
 
 
 class APIKeyManager:
@@ -19,7 +19,7 @@ class APIKeyManager:
 
     def get_api_key(self, provider: str) -> str | None:
         """Get API key for the specified provider using cascading logic."""
-        env_var_name = self._get_env_var_name(provider)
+        env_var_name = self.get_env_var_name(provider)
         service_name = self._get_service_name(provider)
 
         # 1. Check environment variable first
@@ -36,12 +36,12 @@ class APIKeyManager:
                 return api_key
         except Exception as e:
             # Keyring access failed, continue to prompt
-            console.print(f"Keyring access failed: {e}", style="dim yellow")
+            console.print(f"Keyring access failed: {e}", style="warning")
 
         # 3. Prompt user for API key
         return self._prompt_and_store_key(provider, env_var_name, service_name)
 
-    def _get_env_var_name(self, provider: str) -> str:
+    def get_env_var_name(self, provider: str) -> str:
         """Get the expected environment variable name for a provider."""
         # Normalize aliases to canonical provider keys
         key = providers.canonical(provider) or provider
@@ -72,7 +72,7 @@ class APIKeyManager:
             if not api_key.strip():
                 console.print(
                     "No API key provided. Some functionality may not work.",
-                    style="yellow",
+                    style="warning",
                 )
                 return None
 
@@ -83,16 +83,16 @@ class APIKeyManager:
             except Exception as e:
                 console.print(
                     f"Warning: Could not store API key in your operating system's credentials store: {e}",
-                    style="yellow",
+                    style="warning",
                 )
                 console.print(
-                    "You may need to enter it again next time", style="yellow"
+                    "You may need to enter it again next time", style="warning"
                 )
 
             return api_key.strip()
 
         except KeyboardInterrupt:
-            console.print("\nOperation cancelled", style="yellow")
+            console.print("\nOperation cancelled", style="warning")
             return None
         except Exception as e:
             console.print(f"Error prompting for API key: {e}", style="red")
