@@ -3,12 +3,12 @@
 import json
 from typing import Any
 
-from sqlsaber.database.connection import BaseDatabaseConnection
+from sqlsaber.database import BaseDatabaseConnection
 from sqlsaber.database.schema import SchemaManager
 
 from .base import Tool
-from .enums import ToolCategory, WorkflowPosition
 from .registry import register_tool
+from .sql_guard import add_limit, validate_read_only
 
 
 class SQLTool(Tool):
@@ -25,11 +25,6 @@ class SQLTool(Tool):
         self.db = db_connection
         self.schema_manager = SchemaManager(db_connection)
 
-    @property
-    def category(self) -> ToolCategory:
-        """SQL tools belong to the 'sql' category."""
-        return ToolCategory.SQL
-
 
 @register_tool
 class ListTablesTool(SQLTool):
@@ -51,18 +46,6 @@ class ListTablesTool(SQLTool):
             "required": [],
         }
 
-    def get_usage_instructions(self) -> str | None:
-        """Return usage instructions for this tool."""
-        return "ALWAYS start with 'list_tables' to see available tables and row counts. Use this first to discover available tables."
-
-    def get_priority(self) -> int:
-        """Return priority for tool ordering."""
-        return 10  # High priority - should be used first
-
-    def get_workflow_position(self) -> WorkflowPosition:
-        """Return workflow position."""
-        return WorkflowPosition.DISCOVERY
-
     async def execute(self, **kwargs) -> str:
         """List all tables in the database."""
         if not self.db or not self.schema_manager:
@@ -100,18 +83,6 @@ class IntrospectSchemaTool(SQLTool):
             "required": [],
         }
 
-    def get_usage_instructions(self) -> str | None:
-        """Return usage instructions for this tool."""
-        return "Use 'introspect_schema' with a table_pattern to get details ONLY for relevant tables. Use table patterns like 'sample%' or '%experiment%' to filter related tables."
-
-    def get_priority(self) -> int:
-        """Return priority for tool ordering."""
-        return 20  # Should come after list_tables
-
-    def get_workflow_position(self) -> WorkflowPosition:
-        """Return workflow position."""
-        return WorkflowPosition.ANALYSIS
-
     async def execute(self, **kwargs) -> str:
         """Introspect database schema."""
         if not self.db or not self.schema_manager:
@@ -183,18 +154,6 @@ class ExecuteSQLTool(SQLTool):
             "required": ["query"],
         }
 
-    def get_usage_instructions(self) -> str | None:
-        """Return usage instructions for this tool."""
-        return "Execute SQL queries safely with automatic LIMIT clauses for SELECT statements. Only SELECT queries are permitted for security."
-
-    def get_priority(self) -> int:
-        """Return priority for tool ordering."""
-        return 30  # Should come after schema tools
-
-    def get_workflow_position(self) -> WorkflowPosition:
-        """Return workflow position."""
-        return WorkflowPosition.EXECUTION
-
     async def execute(self, **kwargs) -> str:
         """Execute a SQL query."""
         if not self.db:
@@ -207,13 +166,17 @@ class ExecuteSQLTool(SQLTool):
         limit = kwargs.get("limit", self.DEFAULT_LIMIT)
 
         try:
-            # Security check - only allow SELECT queries unless write is enabled
-            write_error = self._validate_write_operation(query)
-            if write_error:
-                return json.dumps({"error": write_error})
+            # Get the dialect for this database
+            dialect = self.db.sqlglot_dialect
+
+            # Security check using sqlglot AST analysis
+            validation_result = validate_read_only(query, dialect)
+            if not validation_result.allowed:
+                return json.dumps({"error": validation_result.reason})
 
             # Add LIMIT if not present and it's a SELECT query
-            query = self._add_limit_to_query(query, limit)
+            if validation_result.is_select and limit:
+                query = add_limit(query, dialect, limit)
 
             # Execute the query
             results = await self.db.execute_query(query)
@@ -249,33 +212,3 @@ class ExecuteSQLTool(SQLTool):
                 )
 
             return json.dumps({"error": error_msg, "suggestions": suggestions})
-
-    def _validate_write_operation(self, query: str) -> str | None:
-        """Validate if a write operation is allowed."""
-        query_upper = query.strip().upper()
-
-        # Check for write operations
-        write_keywords = [
-            "INSERT",
-            "UPDATE",
-            "DELETE",
-            "DROP",
-            "CREATE",
-            "ALTER",
-            "TRUNCATE",
-        ]
-        is_write_query = any(query_upper.startswith(kw) for kw in write_keywords)
-
-        if is_write_query:
-            return (
-                "Write operations are not allowed. Only SELECT queries are permitted."
-            )
-
-        return None
-
-    def _add_limit_to_query(self, query: str, limit: int = 100) -> str:
-        """Add LIMIT clause to SELECT queries if not present."""
-        query_upper = query.strip().upper()
-        if query_upper.startswith("SELECT") and "LIMIT" not in query_upper:
-            return f"{query.rstrip(';')} LIMIT {limit};"
-        return query
